==> ansys_dyna_core-0.7.1.tar.gz: ansys_dyna_core-0.7.1/src/ansys/dyna/core/keywords/keyword_classes/auto/mesh_volume.py <==
# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.series_card import SeriesCard
from ansys.dyna.core.lib.keyword_base import KeywordBase

class MeshVolume(KeywordBase):
    """DYNA MESH_VOLUME keyword"""

    keyword = "MESH"
    subkeyword = "VOLUME"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "volid",
                        int,
                        0,
                        10,
                        **kwargs,
                    ),
                ],
            ),
            SeriesCard(
                "elements",
                8,
                10,
                int,
                None,
                data = kwargs.get("elements")),
        ]

    @property
    def volid(self) -> typing.Optional[int]:
        """Get or set the ID assigned to the new volume
        """ # nopep8
        return self._cards[0].get_value("volid")

    @volid.setter
    def volid(self, value: int) -> None:
        self._cards[0].set_value("volid", value)

    @property
    def elements(self) -> SeriesCard:
        """dynamic array of surface element ids."""
        return self._cards[1]

    @elements.setter
    def elements(self, value: typing.List) -> None:
        self._cards[1].data = value

==> ansys_dyna_core-0.9.0.tar.gz: ansys_dyna_core-0.9.0/src/ansys/dyna/core/keywords/keyword_classes/auto/mesh_volume.py <==
# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Module providing the MeshVolume class."""
import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.series_card import SeriesCard
from ansys.dyna.core.lib.keyword_base import KeywordBase

class MeshVolume(KeywordBase):
    """DYNA MESH_VOLUME keyword"""

    keyword = "MESH"
    subkeyword = "VOLUME"

    def __init__(self, **kwargs):
        """Initialize the MeshVolume class."""
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "volid",
                        int,
                        0,
                        10,
                        **kwargs,
                    ),
                ],
            ),
            SeriesCard(
                "elements",
                8,
                10,
                int,
                None,
                data = kwargs.get("elements")),
        ]

    @property
    def volid(self) -> typing.Optional[int]:
        """Get or set the ID assigned to the new volume
        """ # nopep8
        return self._cards[0].get_value("volid")

    @volid.setter
    def volid(self, value: int) -> None:
        """Set the volid property."""
        self._cards[0].set_value("volid", value)

    @property
    def elements(self) -> SeriesCard:
        """dynamic array of surface element ids.."""
        return self._cards[1]

    @elements.setter
    def elements(self, value: typing.List) -> None:
        self._cards[1].data = value
